@@ -48,8 +48,8 @@ class TickerDax:
         self._redis_image = 'redis:7-alpine3.16'
         self._redis_server_address = os.environ.get(Envs.REDIS_SERVER_ADDRESS, '127.0.0.1')
         self._redis_container_name = f'{NAME}-redis'
-        self._redis_container_port = 6379
-        self._redis_host_port = 6379
+        self._redis_container_port = os.environ.get(Envs.REDIS_SERVER_PORT, 6379)
+        self._redis_host_port = os.environ.get(Envs.REDIS_SERVER_PORT, 6379)
 
         # clients
         self._docker_client = None
