@@ -1,5 +1,7 @@
 from tickerdax.constants import KeyTypes
 from tickerdax.config_base import ConfigBase
+from tickerdax.client import TickerDax
+from tickerdax.downloader import Downloader
 
 
 class Streamer(ConfigBase):
@@ -7,7 +9,18 @@ class Streamer(ConfigBase):
     Streams data from the https://tickerdax.com websocket api to the cache using a provided config.
     """
     def __init__(self, config, client_kwargs=None):
+        # this avoids connecting to the client initially incase the Downloader needs to connect as well
+        client_kwargs['connect'] = False
         super(Streamer, self).__init__(config, client_kwargs)
+
+        # unless told not to, first backwards fill the history from the start date in the config
+        self._back_fill = self._config.get('back_fill', True)
+
+        # if were are not going to use the Downloader, then we need to set the connection
+        if not self._back_fill:
+            client_kwargs['connect'] = True
+            self.client = TickerDax(client_kwargs)
+
         self.stream()
 
     def _validate(self):
@@ -19,18 +32,10 @@ class Streamer(ConfigBase):
         Downloads data from the algo trading REST API base on the bot config files.
         """
         routes = self._config.get('routes', {})
-        back_fill = self._config.get('back_fill', True)
+
         if routes:
-            # unless told not to, first backwards fill the history from the start date in the config
-            if back_fill:
-                for route, symbols in routes.items():
-                    self._logger.info(f'Back filling {route} history from "{self._start}" to "{self._now}"...')
-                    self.client.get_route(
-                        route=route,
-                        symbols=symbols,
-                        start=self._start,
-                        end=self._now,
-                    )
+            if self._back_fill:
+                Downloader(config=self._config_file_path, till_now=True)
 
             # stream updates to the cache indefinitely
             self._logger.info(f'Starting streams...')
